/**
 * C++ Class    L3DGECommunicator
 *
 * Revision     1.0a (9th August 2010)
 * Programmer   Michael Allwright
 *
 * Purpose      L3DGECommunicator creates an interface between the LTCPMON and the L3DGEComms Library
 *              by Lucas Parry. The constructor of this class takes the IP address and port of the remote
 *              server, along with the entities file (aka L3DGEhosts.conf) which lists the entities.
 *              it is important that this file matches the file in use on the server for a clean output
 *
 *              Once the object has been constructed, methods for updating and reseting the visual metrics
 *              of the entity are provided
**/

#ifndef _LTCPMON_L3DGECOMMUNICATOR_
#define _LTCPMON_L3DGECOMMUNICATOR_

#include <string>
#include <vector>
#include <map>

#include "tcpflow.h"
#include "tcpmapping.h"
#include "datascaler.h"
#include "entityfileparser.h"

class L3DGECommunicator
{
    public:
      L3DGECommunicator(const std::string & serverIPAddress, unsigned int serverPort, const std::string & hostsFilename);

      void updateEntities(double fromTimeStamp, const std::map<std::string, TcpFlow> & theTCPSessions,
              const std::vector<TcpMapping> & theVisualMappings);

      void updateEntity(unsigned int entityID, unsigned int visualisationMetric, double value);

      void resetEntities();

      void resetEntity(unsigned int entityID);

    private:

      DataScaler theScaler;
      EntityFileParser entities;

      // hacky buffers for hacky libraries...
      char valueBuffer[50];
      char nameBuffer[50];
      char addressBuffer[50];
};

#endif
