/**
 * C++ Struct   Configuration
 *
 * Revision     1.0a (9th August 2010)
 * Programmer   Michael Allwright
 *
 * Purpose      Defines structure of static runtime values. used for global configuration of runtime
 *              parameters.
 *
 *              This file initialises the static constants defined in configuration.h with default values
 *              Also declares arrays of c-strings which are used for parsing and printing to the screen
 *              The 'H' in the declaration is for 'Human readable', the similar declaration is for parsing.
**/

#include "configuration.h"
#include "tcpmapping.h"

/* Configuration Variables and Constants Initialisation */

double Configuration::visualStartTime = 0;
double Configuration::visualDuration = -1;
double Configuration::updatePeriod = 2;
double Configuration::playbackRatio = 0.5;
std::string Configuration::serverIP = std::string("127.0.0.1");
unsigned int Configuration::serverPort = 27960;
std::string Configuration::mappingsFilename = std::string("");
std::string Configuration::siftrLogFilename = std::string("");
std::string Configuration::entityFilename = std::string("");
bool Configuration::verboseMode = false;
bool Configuration::durationLimitFlag = false;

/* Static and constant data initialisation */
const char Configuration::flowCharacteristics[][FLOW_PARAMS_MAX_STRLEN]
              = { "slowStartThreshold", "currentCongestionWindow",
              "bandwidthControlledWindow", "currentSendingWindow", "currentReceiveWindow",
              "currentSendingWindowScalingFactor", "currentReceivingWindowScalingFactor",
              "maxSegmentSize", "rttEstimate", "retransmissionTimeoutLength",
              "socketSendBufferSize", "bytesInSocketSendBuffer", "socketReceiveBufferSize",
              "bytesInSocketReceiveBuffer", "inflightBytes"};

const char Configuration::flowCharacteristicsH[][FLOW_PARAMS_MAX_STRLEN + 10]
              = { "Slow Start Threshold", "Current Congestion Window",
              "Bandwidth Controlled Window", "Current Sending Window", "Current Receive Window",
              "Current Sending Window Scaling Factor", "Current Receiving Window Scaling Factor",
              "Maximum Segment Size", "RTT Estimate", "Retransmission Timeout Length",
              "Sending Socket Buffer Size", "# Bytes in Send Socket Buffer", "Receiving Socket Buffer Size",
              "# Bytes in Receive Socket Buffer", "In Flight Bytes"};

const unsigned int Configuration::numFlowCharacteristics
              = sizeof(flowCharacteristics)/sizeof(char[FLOW_PARAMS_MAX_STRLEN]);

const char Configuration::statisticsModes[][STATMODES_PARAM_MAX_STRLEN]
              = {"median", "stddev", "minimum", "maximum"};

const char Configuration::statisticsModesH[][STATMODES_PARAM_MAX_STRLEN + 15]
              = {"Median", "Standard Deviation", "Minimum", "Maximum"};

const unsigned int Configuration::numStatisticsModes
              = sizeof(statisticsModes)/sizeof(char[STATMODES_PARAM_MAX_STRLEN]);

// Note: blank ("") visual metric for compatibility with l3dgecomms
const char Configuration::visualisationMetrics[][VISUAL_METRIC_MAX_STRLEN]
              = {"", "spinRate", "bounceHeight", "scale", "roll", "colour", "bounceRate"};

const char Configuration::visualisationMetricsH[][VISUAL_METRIC_MAX_STRLEN + 5]
              = {"", "Spin Rate", "Bounce Height", "Scale", "Roll", "Colour", "Bounce Rate"};

const unsigned int Configuration::numVisualisationMetrics
              = sizeof(visualisationMetrics)/sizeof(char[VISUAL_METRIC_MAX_STRLEN]);
