/**
 * C++ Class    SIFTR Log Parser
 *
 * Revision     1.0a (9th August 2010)
 * Programmer   Michael Allwright
 *
 * Purpose      SIFTR Log Parser is designed to parse log files generated by the SIFTR kernel module (developed by CAIA)
 *              
 **/

#ifndef LTCPMON_SIFTR_LOGPARSER_
#define LTCPMON_SIFTR_LOGPARSER_

#define MAX_SIFTR_FIRST_LINE_LENGTH 200
#define MAX_SIFTR_DATA_LINE_LENGTH 250

#include <fstream>
#include <string>

#include "tcpparams.h"
#include "exceptions.h"

class SiftrLogParser
{
    public:
    /* Constructors */
    SiftrLogParser(const std::string & filename);

    /* Get Methods */
    double getEnableTime() const;
    unsigned int getKernelTickRate() const;
    unsigned int getTcpRttScale() const;
    const std::string & getSiftrVersion() const;

    bool moreDataAvailable() const;
    TcpParams getNextFlowParameters();

    private:
    void parseNextFlowParameters();

    void loadNextLine();

    TcpParams nextFlowParameters;
    bool moreDataFlag;

    const std::string filename;
    std::ifstream logFile;
    std::string nextLine;
    unsigned int dataLinesRead;

    std::string siftrVersion;
    unsigned int kernelTickRate;
    unsigned int tcpRttScale;
    double enableTime;
};

/* inlined methods */
inline
bool SiftrLogParser::moreDataAvailable() const { return moreDataFlag; }

inline
double SiftrLogParser::getEnableTime() const { return enableTime; }

inline
unsigned int SiftrLogParser::getKernelTickRate() const { return kernelTickRate; }

inline
unsigned int SiftrLogParser::getTcpRttScale() const {return tcpRttScale; }

inline
const std::string & SiftrLogParser::getSiftrVersion() const { return siftrVersion; }



#endif
