/**
 * C++ Class    TCPFlow
 *
 * Revision     1.0a (9th August 2010)
 * Programmer   Michael Allwright
 *
 * Purpose      Extention to the STL Vector container class, which has been designed to hold parameters belonging to a
 *              given flow. Class also contains some metadata about the flow, as well as methods to 'grab' a specific
 *              parameter over a given time period.
 *              
 **/

#ifndef _LTCPMON_TCPFLOW_
#define _LTCPMON_TCPFLOW_

#include <iostream>
#include <string>
#include <vector>

#include "tcpparams.h"

class TcpFlow
{
    friend std::ostream & operator<<(std::ostream & theStream, const TcpFlow & theFlow);

    public:
    /* Constructors - default provided for compatibility with STL map, not for general use */
    TcpFlow() : tcpFlowID(""), firstPacketTimestamp(0), lastPacketTimestamp(0) {}
    TcpFlow(const TcpParams & parameters);

    /* Get Methods */
    const std::string & getFlowID() const;
    int getNumberPackets() const;
    int getFirstPacketTimestamp() const;
    int getLastPacketTimestamp() const;

    /* Updating Methods */
    void appendStatsToFlow(const TcpParams & toAppend);

    // get a list of recorded data for a particular parameter
    std::vector<unsigned int> getParameterList(int flowChar, double from, double to) const;    //from 'a' to 'b'
     std::vector<unsigned int> getParameterList(int flowChar, double from) const;        //from 'a' to everything else
    std::vector<unsigned int> getParameterList(int flowChar) const;                // everything
    private:
        std::string tcpFlowID;

    double firstPacketTimestamp;
    double lastPacketTimestamp;

    std::vector<TcpParams> events;
};

/* inlined methods */
inline
const std::string & TcpFlow::getFlowID() const { return tcpFlowID; }

inline
int TcpFlow::getNumberPackets() const { return events.size(); }

inline
int TcpFlow::getFirstPacketTimestamp() const { return firstPacketTimestamp; }

inline
int TcpFlow::getLastPacketTimestamp() const { return lastPacketTimestamp; }
#endif
